<?php

declare(strict_types=1);

namespace Drupal\graphql_compose_webform\Plugin\GraphQLCompose\SchemaType;

use Drupal\graphql_compose\Plugin\GraphQLCompose\GraphQLComposeSchemaTypeBase;
use GraphQL\Type\Definition\ObjectType;
use GraphQL\Type\Definition\Type;

/**
 * {@inheritDoc}
 *
 * @GraphQLComposeSchemaType(
 *   id = "WebformElement"
 * )
 */
class WebformElement extends GraphQLComposeSchemaTypeBase {

  /**
   * {@inheritDoc}
   */
  public function getTypes(): array {
    $types = [];

    // Add the "WebformElement" type.
    $types[] = new ObjectType([
      'name' => $this->getPluginId(),
      'description' => (string) $this->t('A webform element.'),
      'fields' => fn() => [
        'admin_title' => Type::string(),
        'counter_type' => Type::string(),
        'counter_minimum' => Type::int(),
        'counter_maximum' => Type::int(),
        'counter_maximum_message' => Type::string(),
        'id' => Type::string(),
        'options' => Type::listOf(static::type('WebformElementOption')),
        'pattern' => Type::string(),
        'pattern_error' => Type::string(),
        'placeholder' => Type::string(),
        'required' => Type::boolean(),
        'required_error' => Type::string(),
        'states' => Type::listOf(static::type('WebformElementState')),
        'title' => Type::string(),
        'type' => Type::string(),
        'unique' => Type::boolean(),
        'unique_entity' => Type::boolean(),
        'unique_user' => Type::boolean(),
        'unique_error' => Type::string(),
        'webform_children' => Type::listOf(Type::string()),
        'webform_composite' => Type::boolean(),
        'webform_depth' => Type::int(),
        'webform_id' => Type::string(),
        'webform_key' => Type::string(),
        'webform_multiple' => Type::boolean(),
        'webform_parent_flexbox' => Type::string(),
        'webform_parents' => Type::listOf(Type::string()),
        'webform_plugin_id' => Type::string(),
        'webform' => Type::string(),
      ],
    ]);

    return $types;
  }

}
